pub struct Task {
pub id: TaskId,
pub partition_id: PartitionId,
pub operation: TaskOperation,
pub status: TaskStatus,
pub worker_id: Option<String>,
pub retry_count: u32,
pub max_retries: u32,
}Expand description
A task to be executed by a worker.
Fields
id: TaskIdUnique task identifier.
partition_id: PartitionIdPartition to process.
operation: TaskOperationOperation to perform.
status: TaskStatusCurrent status.
worker_id: Option<String>Worker ID assigned to this task (if any).
retry_count: u32Number of retry attempts.
max_retries: u32Maximum number of retries allowed.
Implementations
Sourceimpl Task
impl Task
Sourcepub fn new(
id: TaskId,
partition_id: PartitionId,
operation: TaskOperation,
) -> Self
pub fn new( id: TaskId, partition_id: PartitionId, operation: TaskOperation, ) -> Self
Create a new task.
Sourcepub fn mark_running(&mut self, worker_id: String)
pub fn mark_running(&mut self, worker_id: String)
Mark the task as running on a specific worker.
Sourcepub fn mark_completed(&mut self)
pub fn mark_completed(&mut self)
Mark the task as completed.
Sourcepub fn mark_failed(&mut self)
pub fn mark_failed(&mut self)
Mark the task as failed and increment retry count.
Sourcepub fn mark_cancelled(&mut self)
pub fn mark_cancelled(&mut self)
Mark the task as cancelled.
Sourcepub fn reset_for_retry(&mut self)
pub fn reset_for_retry(&mut self)
Reset the task for retry.